@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-__version__ = "0.13.1"
+__version__ = "0.14.0"
 
 import asyncio
 from typing import Any, Mapping, Optional, Tuple, Union
@@ -10,16 +10,22 @@ from aiohttp import hdrs
 from rich import print
 
 from .client import Client
-from .models.binance import BinanceDataStore
+from .models.binance import (
+    BinanceCOINMDataStore,
+    BinanceSpotDataStore,
+    BinanceUSDSMDataStore,
+)
 from .models.bitbank import bitbankDataStore
 from .models.bitflyer import bitFlyerDataStore
 from .models.bitget import BitgetDataStore
 from .models.bitmex import BitMEXDataStore
 from .models.bybit import BybitInverseDataStore, BybitUSDTDataStore
 from .models.coincheck import CoincheckDataStore
+from .models.deprecated.binance import BinanceDataStore
 from .models.deprecated.bybit import BybitDataStore
 from .models.ftx import FTXDataStore
 from .models.gmocoin import GMOCoinDataStore
+from .models.kucoin import KuCoinDataStore
 from .models.okx import OKXDataStore
 from .models.phemex import PhemexDataStore
 from .typedefs import WsJsonHandler, WsStrHandler
@@ -37,11 +43,15 @@ __all__: Tuple[str, ...] = (
     "BybitUSDTDataStore",
     "FTXDataStore",
     "BinanceDataStore",
+    "BinanceSpotDataStore",
+    "BinanceUSDSMDataStore",
+    "BinanceCOINMDataStore",
     "bitbankDataStore",
     "bitFlyerDataStore",
     "BitgetDataStore",
     "BitMEXDataStore",
     "GMOCoinDataStore",
+    "KuCoinDataStore",
     "OKXDataStore",
     "PhemexDataStore",
     "experimental",
