@@ -242,7 +242,9 @@ class Positions(DataStore):
 
     def _onresponse(self, data: list[Item]) -> None:
         if data:
-            self._delete(self.find({"product_code": data[0]["product_code"]}))
+            positions = self._find_with_uuid({"product_code": data[0]["product_code"]})
+            if positions:
+                self._remove(list(positions.keys()))
             for item in data:
                 self._insert([self._common_keys(item)])
 
@@ -260,11 +262,13 @@ class Positions(DataStore):
                                     item["size"], int
                                 ):
                                     pos["size"] -= item["size"]
+                                    item["size"] = 0
                                 else:
                                     pos["size"] = float(
                                         Decimal(str(pos["size"]))
                                         - Decimal(str(item["size"]))
                                     )
+                                    item["size"] = 0.0
                                 break
                             else:
                                 if isinstance(pos["size"], int) and isinstance(
@@ -277,8 +281,8 @@ class Positions(DataStore):
                                         - Decimal(str(pos["size"]))
                                     )
                                 self._remove([uid])
-                                if not pos["size"]:
-                                    break
+                        if item["size"] > 0:
+                            self._insert([self._common_keys(item)])
                 else:
                     try:
                         self._insert([self._common_keys(item)])
